require 'spec_helper'

describe CloudFormer::HasPropertiesAndAttributes do
  let(:template) { CloudFormer::Template.new }

  it "builds simple resources correctly" do
    instance = CloudFormer::EC2::Instance.new('myinstance') do
      availability_zone 'us-east-1'
      image_id 'ami-123456'
    end
    template.add_resource(instance)

    expect(template.dump_json).to eq(
      "AWSTemplateFormatVersion" => "2010-09-09",
      "Resources" => {
        "myinstance" => {
          "Type" => "AWS::EC2::Instance",
          "Properties" => {
            "AvailabilityZone" => "us-east-1",
            "ImageId" => "ami-123456",
          },
        },
      },
    )
  end

  it "supports builds nested resource properties via blocks" do
    instance = CloudFormer::EC2::Instance.new('myinstance') do
      # list
      block_device_mappings(2) do |i|
        device_name "/dev/sdf".tap { |s| i.times { s.succ! } }
        # single
        ebs do
          volume_size 100
          volume_type 'standard'
        end
      end
    end
    template.add_resource(instance)

    expect(template.dump_json).to eq(
      "AWSTemplateFormatVersion" => "2010-09-09",
      "Resources" => {
        "myinstance" => {
          "Type" => "AWS::EC2::Instance",
          "Properties" => {
            "BlockDeviceMappings" => [
              {
                "DeviceName" => "/dev/sdf",
                "Ebs" => {
                  "VolumeSize" => 100,
                  "VolumeType" => "standard",
                },
              },
              {
                "DeviceName" => "/dev/sdg",
                "Ebs" => {
                  "VolumeSize" => 100,
                  "VolumeType" => "standard",
                },
              },
            ],
          },
        },
      },
    )
  end
end
