require 'spec_helper'

describe CloudFormer::AutoScaling::AutoScalingGroup do

  let(:group) do
    notification_config = CloudFormer::AutoScaling::NotificationConfiguration.new do
      topic_arn 'abc'
      notification_types [
        CloudFormer::AutoScaling::NotificationConfiguration::LAUNCH_ERROR
      ]
    end

    CloudFormer::AutoScaling::AutoScalingGroup.new('ASG') do
      cooldown 30
      notification_configuration notification_config
      availability_zones CloudFormer::Functions::GetAZs.new
    end
  end

  it 'should make some awesome json' do
    expect(group.dump_json).to eq({
      "Type" => "AWS::AutoScaling::AutoScalingGroup",
      "Properties" => {
        "NotificationConfiguration" => {
          "NotificationTypes" => ["autoscaling:EC2_INSTANCE_LAUNCH_ERROR"],
          "TopicARN" => "abc",
        },
        "Cooldown" => 30,
        "AvailabilityZones" => { "Fn::GetAZs" => "" }
      }
    })
  end

  describe 'with an update policy' do

    let(:policy) do
      CloudFormer::AutoScaling::UpdatePolicy.new do
        max_batch_size 10
        min_instances_in_service 1
        pause_time 'PT12M5S'
      end
    end

    before do
      group.update_policy(policy)
    end

    it 'should make awesome json' do
      expect(group.dump_json).to eq({
        "Type" => "AWS::AutoScaling::AutoScalingGroup",
        "Properties" => {
          "NotificationConfiguration" => {
            "NotificationTypes" => ["autoscaling:EC2_INSTANCE_LAUNCH_ERROR"],
            "TopicARN" => "abc",
          },
          "Cooldown" => 30,
          "AvailabilityZones" => { "Fn::GetAZs" => "" }
        },
        "UpdatePolicy" => {
          "AutoScalingRollingUpdate" => {
            "MaxBatchSize"=>10,
            "MinInstancesInService"=>1,
            "PauseTime"=>"PT12M5S"
          }
        }
      })
    end
  end
end
