require 'spec_helper'

describe CloudFormer::IAM::AccessKey do

  let(:access_key) do
    CloudFormer::IAM::AccessKey.new('key') do
      serial 1
      status 'Active'
      user_name 'aubrey'
    end
  end

  it 'should let me get the status' do
    expect(access_key.status).to eq('Active')
  end

  it 'should make some awesome json' do
    expect(access_key.dump_json).to eq({
      'Type' => 'AWS::IAM::AccessKey',
      'Properties' => {
        'Serial' => 1,
        'Status' => 'Active',
        'UserName' => 'aubrey'
      }
    })
  end

  it 'should be able to use a reference to a parameter' do
    param = CloudFormer::StringParameter.new('ack')
    access_key = CloudFormer::IAM::AccessKey.new('KEY') do
      user_name param
    end
    expect(access_key.dump_json).to eq({
      'Type' => 'AWS::IAM::AccessKey',
      'Properties' => {
        'UserName' => {
          'Ref' => 'ack'
        }
      }
    })
  end

end
