require 'spec_helper'

describe CloudFormer::List do
  let(:template) { CloudFormer::Template.new }

  it "can build a list of resource properties" do
    instance = CloudFormer::EC2::Instance.new('instance') do
      tags :list do
        entry do
          key 'A'
          value '1'
        end

        entry do
          key 'B'
          value '2'
        end
      end
    end

    template.add_resource(instance)

    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
      'Resources' => {
        'instance' => {
          'Type' => 'AWS::EC2::Instance',
          'Properties' => {
            'Tags' => [
              {
                'Key' => 'A',
                'Value' => '1',
              },
              {
                'Key' => 'B',
                'Value' => '2',
              },
            ],
          },
        },
      },
    )
  end

  it "can build a list of resources" do
    instance = CloudFormer::EC2::Instance.new('instance') do
      network_interfaces :list do
        entry do
          description 'one'
        end

        entry do
          description 'two'
        end
      end
    end

    template.add_resource(instance)

    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
      'Resources' => {
        'instance' => {
          'Type' => 'AWS::EC2::Instance',
          'Properties' => {
            'NetworkInterfaces' => [
              {
                'Description' => 'one',
              },
              {
                'Description' => 'two',
              },
            ],
          },
        },
      },
    )
  end
end
