require 'spec_helper'

describe CloudFormer::Route53 do
  let(:template) { CloudFormer::Template.new }

  it "supports hosted zones" do
    hosted_zone = CloudFormer::Route53::HostedZone.new('hosted_zone') do
      hosted_zone_config do
        comment 'COMMENT'
      end
      hosted_zone_tags(1) do
        key 'KEY'
        value 'VALUE'
      end
      _name 'NAME'
      vpcs(1) do
        vpc_id 'VPC ID'
        vpc_region 'VPC REGION'
      end
    end
    template.add_resource(hosted_zone)

    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
      'Resources' => {
        'hosted_zone' => {
          'Type' => 'AWS::Route53::HostedZone',
          'Properties' => {
            'HostedZoneConfig' => {
              'Comment' => 'COMMENT',
            },
            'HostedZoneTags' => [
              {
                'Key' => 'KEY',
                'Value' => 'VALUE',
              },
            ],
            'Name' => 'NAME',
            'VPCs' => [
              {
                'VPCId' => 'VPC ID',
                'VPCRegion' => 'VPC REGION',
              },
            ],
          },
        }
      }
    )
  end

  it "supports record set groups" do
    record_set = CloudFormer::Route53::RecordSet.new('record_set') do
      alias_target do
        dns_name 'DNS NAME'
        evaluate_target_health true
        hosted_zone_id 'HOSTED ZONE ID'
      end
      comment 'COMMENT'
      failover 'FAILOVER'
      geo_location do
        continent_code 'CONTINENT CODE'
        country_code 'COUNTRY CODE'
        subdivision_code 'SUBDIVISION CODE'
      end
      health_check_id 'HEALTH CHECK ID'
      hosted_zone_id 'HOSTED ZONE ID'
      hosted_zone_name 'HOSTED ZONE NAME'
      _name 'NAME'
      region 'REGION'
      resource_records ['RESOURCE RECORD']
      set_identifier 'SET IDENTIFIER'
      ttl 'TTL'
      type 'TYPE'
      weight 2
    end
    template.add_resource(record_set)

    record_set_group = CloudFormer::Route53::RecordSetGroup.new('record_set_group') do
      hosted_zone_id 'HOSTED ZONE ID'
      hosted_zone_name 'HOSTED ZONE NAME'
      record_sets [record_set]
      comment 'COMMENT'
    end
    template.add_resource(record_set_group)

    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
      'Resources' => {
        'record_set' => {
          'Type' => 'AWS::Route53::RecordSet',
          'Properties' => {
            'AliasTarget' => {
              'DNSName' => 'DNS NAME',
              'EvaluateTargetHealth' => true,
              'HostedZoneId' => 'HOSTED ZONE ID',
            },
            'Comment' => 'COMMENT',
            'Failover' => 'FAILOVER',
            'GeoLocation' => {
              'ContinentCode' => 'CONTINENT CODE',
              'CountryCode' => 'COUNTRY CODE',
              'SubdivisionCode' => 'SUBDIVISION CODE',
            },
            'HealthCheckId' => 'HEALTH CHECK ID',
            'HostedZoneId' => 'HOSTED ZONE ID',
            'HostedZoneName' => 'HOSTED ZONE NAME',
            'Name' => 'NAME',
            'Region' => 'REGION',
            'ResourceRecords' => ['RESOURCE RECORD'],
            'SetIdentifier' => 'SET IDENTIFIER',
            'TTL' => 'TTL',
            'Type' => 'TYPE',
            'Weight' => 2,
          },
        },
        'record_set_group' => {
          'Type' => 'AWS::Route53::RecordSetGroup',
          'Properties' => {
            'HostedZoneId' => 'HOSTED ZONE ID',
            'HostedZoneName' => 'HOSTED ZONE NAME',
            'RecordSets' => [{'Ref' => 'record_set'}],
            'Comment' => 'COMMENT',
          },
        },
      },
    )
  end
end
