require 'spec_helper'

describe CloudFormer::Template do
  let(:template) { CloudFormer::Template.new }
  let(:parameter) { CloudFormer::StringParameter.new('sweet') }
  let(:resource) do
    CloudFormer::IAM::AccessKey.new('KEY') do
      status 'Active'
      user_name 'Aubrey'
    end
  end

  it 'should produce JSON' do
    expect(template.dump_json).to be_an_instance_of(Hash)
  end

  it 'should include the AWSTemplateFormatVersion by default' do
    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
    )
  end

  it 'should include parameters' do
    template.add_parameter(parameter)
    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
      'Parameters' => {
        'sweet' => {
          'Type' => 'String',
        },
      },
    )
  end

  it 'should include resources' do
    template.add_resource(resource)
    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
      'Resources' => {
        resource.get_name => {
          'Type' => resource.aws_type,
          'Properties' => {
            'Status' => 'Active',
            'UserName' => 'Aubrey',
          },
        },
      },
    )
  end

  it "can add resources inline" do
    resource = template.add_resource 'ec2.instance', 'MyInstance' do
      availability_zone 'us-east-1a'
    end
    expect(template.dump_json).to eq(
      'AWSTemplateFormatVersion' => '2010-09-09',
      'Resources' => {
        'MyInstance' => {
          'Type' => 'AWS::EC2::Instance',
          'Properties' => {
            'AvailabilityZone' => 'us-east-1a',
          },
        },
      },
    )
    expect(resource).to be_a(CloudFormer::EC2::Instance)
  end
end
